View source: R/ComputeMatrix.R
| CMIBiCondimat2matAll | R Documentation |
Computes the normalized conditional mutual information (CMI) between each row of first matrix and each row of second matrix, given two condition variables, normalized by their individual information content. CMI is calculated using the specified number of bins and spline order.
CMIBiCondimat2matAll(mat1, mat2, condi1, condi2, bin = NULL, sp_order = NULL)
mat1 |
A numeric matrix. For example, each row represents a gene and each column represents a sample. |
mat2 |
Another numeric matrix to compare against. Must have the same columns as 'mat1'. |
condi1 |
A numeric condition vector, matching the number of columns in 'mat1'. |
condi2 |
Another numeric condition vector, matching the number of columns in 'mat1'. |
bin |
An integer specifying the number of bins. Default is NULL. |
sp_order |
An integer specifying the spline order. Must be less than 'bin'. Default is NULL. |
A matrix where each element corresponds to the normalized conditional mutual information (CMI) between each row of 'mat1' and each row of 'mat2', conditioned on 'condi1' and 'condi2'.
mat1 <- matrix(rnorm(1000), nrow = 10, ncol = 100)
mat2 <- matrix(rnorm(20000), nrow = 200, ncol = 100)
condi1 <- rnorm(100)
condi2 <- rnorm(100)
CMIBiCondimat2matAll(mat1, mat2, condi1, condi2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.