CMIBiCondimat2vecPermu: Permuted Normalized Conditional Mutual Information Between Matrix and Vector Given Two Conditions
Description
Computes the conditional mutual information (CMI) between a random vector sampled from a matrix and a vector,
conditioned on two vectors, normalized by the mutual information of the vector with itself.
The sampling is done multiple times to generate a distribution.