CMImat2matAll: Normalized Conditional Mutual Information Between Each Row of...

View source: R/ComputeMatrix.R

CMImat2matAllR Documentation

Normalized Conditional Mutual Information Between Each Row of Two Matrices

Description

Computes the normalized conditional mutual information (CMI) between each row of first matrix and each row of second matrix, given a condition variable, normalized by their individual information content. CMI is calculated using the specified number of bins and spline order.

Usage

CMImat2matAll(mat1, mat2, condi, bin = NULL, sp_order = NULL)

Arguments

mat1

A numeric matrix. For example, each row represents a gene and each column represents a sample.

mat2

Another numeric matrix to compare against. Must have the same columns as 'mat1'.

condi

A numeric condition vector, matching the number of columns in 'mat1'.

bin

An integer specifying the number of bins. Default is NULL.

sp_order

An integer specifying the spline order. Must be less than 'bin'. Default is NULL.

Value

A matrix where each element corresponds to the normalized conditional mutual information (CMI) between each row of 'mat1' and each row of 'mat2', conditioned on 'condi'.

Examples

mat1 <- matrix(rnorm(1000), nrow = 10, ncol = 100)
mat2 <- matrix(rnorm(20000), nrow = 200, ncol = 100)
condi <- rnorm(100)
CMImat2matAll(mat1, mat2, condi)


conMItion documentation built on June 17, 2026, 5:06 p.m.