View source: R/ComputeMatrix.R
| MImat2mat | R Documentation |
Computes the normalized mutual information (MI) between the same rows of two matrices normalized by their individual information content, using the specified number of bins and spline order.
MImat2mat(mat1, mat2, bin = NULL, sp_order = NULL)
mat1 |
A numeric matrix. For example, each row represents a gene and each column represents a sample. |
mat2 |
Another numeric matrix to compare against. Must have the same dimensions as 'mat1'. |
bin |
An integer specifying the number of bins. Default is NULL. |
sp_order |
An integer specifying the spline order. Must be less than 'bin'. Default is NULL. |
A numeric vector where each element corresponds to the normalized mutual information (MI) between respective rows of 'mat1' and 'mat2'.
mat1 <- matrix(rnorm(10000), nrow = 100, ncol = 100)
mat2 <- matrix(rnorm(10000), nrow = 100, ncol = 100)
MImat2mat(mat1, mat2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.