MImat2vecPermu: Permuted Normalized Mutual Information Between Matrix and Vector
Description
Computes the mutual information (MI) between a random vector sampled from a matrix and a vector,
normalized by the mutual information of the vector with itself. The sampling is done multiple times to generate a distribution.