getCMI: Calculate Conditional Mutual Information

View source: R/ComputeMutualInformation.R

getCMIR Documentation

Calculate Conditional Mutual Information

Description

Computes the conditional mutual information I(x_1; x_2 | x_3) using the specified number of bins and spline order.

Usage

getCMI(x_1, x_2, x_3, bin = NULL, sp_order = NULL)

Arguments

x_1

A numeric vector for the first variable.

x_2

A numeric vector for the second variable. Must match 'x_1' length.

x_3

A numeric vector for the condition variable. Must match 'x_1' length.

bin

An integer specifying the number of bins. Default is NULL.

sp_order

An integer specifying the spline order. Must be less than 'bin'. Default is NULL.

Value

A numeric value representing the conditional mutual information (CMI).

Examples

x_1 <- rnorm(100)
x_2 <- rnorm(100)
x_3 <- rnorm(100)
getCMI(x_1, x_2, x_3)


conMItion documentation built on May 26, 2026, 5:06 p.m.

Related to getCMI in conMItion...