getCMIBiCondi: Calculate Bivariate Conditional Mutual Information

View source: R/ComputeMutualInformation.R

getCMIBiCondiR Documentation

Calculate Bivariate Conditional Mutual Information

Description

Computes conditional mutual information I(x_1; x_2 | x_3, x_4) using the specified number of bins and spline order.

Usage

getCMIBiCondi(x_1, x_2, x_3, x_4, bin = NULL, sp_order = NULL)

Arguments

x_1

A numeric vector for the first variable.

x_2

A numeric vector for the second variable. Must match 'x_1' length.

x_3

A numeric vector for the first condition variable. Must match 'x_1' length.

x_4

A numeric vector for the second condition variable. Must match 'x_1' length.

bin

An integer specifying the number of bins. Default is NULL.

sp_order

An integer specifying the spline order. Must be less than 'bin'. Default is NULL.

Value

A numeric value representing the bivariate conditional mutual information (CMI).

Examples

x_1 <- rnorm(100)
x_2 <- rnorm(100)
x_3 <- rnorm(100)
x_4 <- rnorm(100)
getCMIBiCondi(x_1, x_2, x_3, x_4)


conMItion documentation built on May 26, 2026, 5:06 p.m.