getEntropy: Calculate Univariate Entropy

View source: R/ComputeEntropy.R

getEntropyR Documentation

Calculate Univariate Entropy

Description

This function calculates the univariate entropy of a numeric vector using the specified number of bins and spline order.

Usage

getEntropy(x_1, bin = NULL, sp_order = NULL)

Arguments

x_1

A numeric vector for the only variable.

bin

An integer specifying the number of bins. Default is NULL.

sp_order

An integer specifying the spline order. Must be less than 'bin'. Default is NULL.

Value

A numeric value representing the entropy of the vector.

Examples

x_1 <- rnorm(100)
getEntropy(x_1)


conMItion documentation built on June 17, 2026, 5:06 p.m.