View source: R/ComputeEntropy.R
| getEntropyTri | R Documentation |
Computes the joint entropy of three numeric vectors using the specified number of bins and spline order.
getEntropyTri(x_1, x_2, x_3, bin = NULL, sp_order = NULL)
x_1 |
A numeric vector for the first variable. |
x_2 |
A numeric vector for the second variable. Must be the same length as 'x_1'. |
x_3 |
A numeric vector for the third variable. Must be the same length as 'x_1'. |
bin |
An integer specifying the number of bins. Default is NULL. |
sp_order |
An integer specifying the spline order. Must be less than 'bin'. Default is NULL. |
A numeric value representing the joint entropy of the three vectors.
x_1 <- rnorm(100)
x_2 <- rnorm(100)
x_3 <- rnorm(100)
getEntropyTri(x_1, x_2, x_3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.