CMIBiCondimat2matPermu: Permuted Conditional Mutual Information Between Two Matrices Given Two Conditions
Description
Computes the normalized conditional mutual information (CMI) between vectors sampled from two matrices,
conditioned on two vectors, normalized by the individual information content.
The sampling is done multiple times to generate a distribution.