CMImat2matPermu: Permuted Conditional Mutual Information Between Two Matrices
Description
Computes the normalized conditional mutual information (CMI) between vectors sampled from two matrices,
conditioned on another vector, normalized by the individual information content. The sampling is done multiple times to generate a distribution.