MImat2mat: Normalized Mutual Information Between Two Matrices
Description
Computes the normalized mutual information (MI) between corresponding rows of two matrices
normalized by their individual information content, using the specified number of bins and spline order.
Usage
MImat2mat(mat1, mat2, bin = 6, sp_order = 2)
Value
A numeric vector where each element corresponds to the normalized mutual information (MI) between
respective rows of `mat1` and `mat2`.
Arguments
mat1
A numeric matrix. For example, each row represents a gene and each column represents a sample.
mat2
Another numeric matrix to compare against. Must have the same dimensions as `mat1`.
bin
An integer specifying the number of bins. Default is 6.
sp_order
An integer specifying the spline order. Must be less than `bin`. Default is 2.