MImat2matPermu: Permuted Mutual Information Between Two Matrices
Description
Computes the normalized mutual information (MI) between vectors sampled from two matrices normalized by the individual information content.
The sampling is done multiple times to generate a distribution.