Learn R Programming

conMItion (version 0.2.1)

getCMI: Calculate Conditional Mutual Information

Description

Computes the conditional mutual information I(x_1; x_2 | x_3) using the specified number of bins and spline order.

Usage

getCMI(x_1, x_2, x_3, bin = 6, sp_order = 2)

Value

A numeric value representing the conditional mutual information (CMI).

Arguments

x_1

A numeric vector for the first variable.

x_2

A numeric vector for the second variable. Must match `x_1` length.

x_3

A numeric vector for the condition variable. Must match `x_1` length.

bin

An integer specifying the number of bins. Default is 6.

sp_order

An integer specifying the spline order. Must be less than `bin`. Default is 2.

Examples

Run this code
x_1 <- rnorm(100)
x_2 <- rnorm(100)
x_3 <- rnorm(100)
getCMI(x_1, x_2, x_3)

Run the code above in your browser using DataLab