View source: R/ComputeEntropy.R
| getEntropy | R Documentation |
This function calculates the univariate entropy of a numeric vector using the specified number of bins and spline order.
getEntropy(x_1, bin = NULL, sp_order = NULL)
x_1 |
A numeric vector for the only variable. |
bin |
An integer specifying the number of bins. Default is NULL. |
sp_order |
An integer specifying the spline order. Must be less than 'bin'. Default is NULL. |
A numeric value representing the entropy of the vector.
x_1 <- rnorm(100)
getEntropy(x_1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.