View source: R/helper_params.R
| resolve_params | R Documentation |
Resolves and validates the bin and sp_order parameters.
If bin is not provided or valid, both bin and sp_order are generated automatically.
If bin is valid but sp_order is not provided or valid, only sp_order is generated.
This function is intended for internal use only and should not be accessed by package users.
resolve_params(n, bin = NULL, sp_order = NULL)
n |
Integer. Length of the input vector. |
bin |
Number or |
sp_order |
Number or |
A list containing the validated or automatically generated values
bin and sp_order.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.